@@ -1,4 +1,4 @@
-### $Id: zzMethods.R,v 1.3 2001/06/18 21:16:49 bates Exp $
+### $Id: zzMethods.R,v 1.4 2001/10/30 20:51:14 bates Exp $
 ###
 ###   Miscellaneous methods that must be defined last in the library
 ###
@@ -36,3 +36,7 @@ qqnorm.gls <- qqnorm.lm <- .Alias(qqnorm.nls)
 
 plot.lme <- .Alias(plot.nls)
 
+fitted.gnls <- fitted.gls
+
+residuals.gnls <- residuals.gls
+
